ComputedHub<R, S> class

ComputedHub extends Hub

Inheritance

Constructors

ComputedHub(R initialValue, R selector(S), Hub<S> source)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → R
no setterinherited

Methods

dispose() → void
override
listen(HubListener<R> listener) Disposable
inherited
listenNow(void listener(R value)) Disposable
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select<R>(R selector(R value)) ComputedHub<R, R>
inherited
set(R newValue) → void
inherited
toString() String
A string representation of this object.
inherited
update(R transform(R current)) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited