Hub<T> class
- Implementers
Constructors
- Hub(T _value)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
no setter
Methods
-
dispose(
) → void -
listen(
HubListener< T> listener) → Disposable -
listenNow(
void listener(T value)) → Disposable -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
select<
R> (R selector(T value)) → ComputedHub< R, T> -
set(
T newValue) → void -
toString(
) → String -
A string representation of this object.
override
-
update(
T transform(T current)) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited